<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_custom_course_menu', language 'id', version '5.0'.
 *
 * @package     block_custom_course_menu
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['privacy:metadata:block_custom_course_menu:block_custom_course_menu'] = 'Lacak status yang diciutkan/diluaskan untuk kategori per pengguna. Simpan preferensi pengguna untuk blok menu kustom';
$string['privacy:metadata:block_custom_course_menu:block_custom_course_menu:categoryid'] = 'ID kategori diciutkan atau diluaskan untuk pengguna tertentu';
$string['privacy:metadata:block_custom_course_menu:block_custom_course_menu:collapsed'] = 'Status diciutkan/diluaskan untuk pengguna tertentu dan kategori tertentu. 1 untuk diciutkan, 0 untuk diluaskan';
$string['privacy:metadata:block_custom_course_menu:block_custom_course_menu:textcontext'] = 'status diciutkan atau diluaskan';
$string['privacy:metadata:block_custom_course_menu:block_custom_course_menu:userid'] = 'Userid yang terkait dengan status kategori yang diciutkan/diluaskan ini';
